@@ -33,14 +33,16 @@ av_meta_reader_class_init (AVMetaReaderClass *klass)
 
 G_DEFINE_TYPE (AVMetaReader, av_meta_reader, G_TYPE_OBJECT)
 
-gboolean av_meta_reader_read (AVMetaReader *reader,
-			      DmapAvRecord *record,
-			      const gchar *path)
+gboolean
+av_meta_reader_read (AVMetaReader *reader,
+                     DmapAvRecord *record,
+                     const gchar *path)
 {
 	return AV_META_READER_GET_CLASS (reader)->read (reader, record, path);
 }
 
-GOptionGroup *av_meta_reader_get_option_group (AVMetaReader *reader)
+GOptionGroup *
+av_meta_reader_get_option_group (AVMetaReader *reader)
 {
 	return AV_META_READER_GET_CLASS (reader)->get_option_group (reader);
 }
