@@ -50,16 +50,18 @@ struct _DbBuilder {
 struct _DbBuilderClass {
         GObjectClass parent;
 
-	void (*build_db_starting_at) (DbBuilder *builder,
-                                      const char *dir,
-                                      DmapContainerRecord *container_record);
+	gboolean (*build_db_starting_at) (DbBuilder *builder,
+	                                  const char *dir,
+	                                  DmapContainerRecord *container_record,
+	                                  GError **error);
 };
 
 GType       db_builder_get_type      (void);
 
-void db_builder_build_db_starting_at (DbBuilder *builder,
-				      const char *dir,
-				      DmapContainerRecord *container_record);
+gboolean db_builder_build_db_starting_at (DbBuilder *builder,
+                                          const char *dir,
+                                          DmapContainerRecord *container_record,
+                                          GError **error);
 
 #endif /* __DB_BUILDER */
 
