@@ -37,7 +37,7 @@ enum {
  * Container ID's start at 1 and go up.
  * 1 is reserved for the primary container.
  */
-static gint nextid = 2;
+static gint _nextid = 2;
 
 struct DmapdDmapContainerRecordPrivate {
 	gint id;
@@ -52,10 +52,10 @@ struct DBPair {
 };
 
 static void
-dmapd_dmap_container_record_set_property (GObject *object,
-					  guint prop_id,
-					  const GValue *value,
-					  GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
 	DmapdDmapContainerRecord *record = DMAPD_DMAP_CONTAINER_RECORD (object);
 
@@ -65,8 +65,9 @@ dmapd_dmap_container_record_set_property (GObject *object,
 			record->priv->name = g_value_dup_string (value);
 			break;
 		case PROP_FULL_DB:
-			if (record->priv->full_db)
+			if (record->priv->full_db) {
 				g_object_unref (record->priv->full_db);
+			}
 			record->priv->full_db = DMAP_DB (g_value_get_pointer (value));
 			break;
 		default:
@@ -76,10 +77,7 @@ dmapd_dmap_container_record_set_property (GObject *object,
 }
 
 static void
-dmapd_dmap_container_record_get_property (GObject *object,
-					  guint prop_id,
-					  GValue *value,
-					  GParamSpec *pspec)
+_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	DmapdDmapContainerRecord *record = DMAPD_DMAP_CONTAINER_RECORD (object);
 
@@ -97,15 +95,15 @@ dmapd_dmap_container_record_get_property (GObject *object,
 }
 
 static guint
-dmapd_dmap_container_record_get_id (DmapContainerRecord *record)
+_get_id (DmapContainerRecord *record)
 {
 	return DMAPD_DMAP_CONTAINER_RECORD (record)->priv->id;
 }
 
 // NOTE: ignores record parameter.
 static void
-dmapd_dmap_container_record_add_entry (DmapContainerRecord *container_record,
-				       DmapRecord *record, gint id)
+_add_entry (DmapContainerRecord *container_record,
+            DmapRecord *record, gint id, GError **error)
 {
 	DmapdDmapContainerRecordPrivate *priv = 
 		DMAPD_DMAP_CONTAINER_RECORD (container_record)->priv;
@@ -113,25 +111,26 @@ dmapd_dmap_container_record_add_entry (DmapContainerRecord *container_record,
 }
 
 static guint64
-dmapd_dmap_container_record_get_entry_count (DmapContainerRecord *record)
+_get_entry_count (DmapContainerRecord *record)
 {
 	return g_slist_length
 		(DMAPD_DMAP_CONTAINER_RECORD (record)->priv->entries);
 }
 
 static void
-add_to_db (void *item, struct DBPair *pair)
+_add_to_db (void *item, struct DBPair *pair)
 {
 	DmapRecord *record = dmap_db_lookup_by_id (pair->src,
 						   GPOINTER_TO_UINT (item));
 	g_debug ("Adding record %u to container DB", GPOINTER_TO_UINT (item));
 	dmap_db_add_with_id (pair->dest,
-			     record,
-			     GPOINTER_TO_UINT (item));
+	                     record,
+	                     GPOINTER_TO_UINT (item),
+	                     NULL);
 }
 
 static DmapDb *
-dmapd_dmap_container_record_get_entries (DmapContainerRecord *record)
+_get_entries (DmapContainerRecord *record)
 {
 	struct DBPair pair;
 
@@ -141,7 +140,7 @@ dmapd_dmap_container_record_get_entries (DmapContainerRecord *record)
 	g_assert (DMAPD_DMAP_CONTAINER_RECORD (record)->priv->entries != NULL);
 
 	g_slist_foreach (DMAPD_DMAP_CONTAINER_RECORD (record)->priv->entries,
-			 (GFunc) add_to_db,
+			 (GFunc) _add_to_db,
 			 &pair);
 	
 	return pair.dest;
@@ -151,13 +150,13 @@ static void
 dmapd_dmap_container_record_init (DmapdDmapContainerRecord *record)
 {
 	record->priv = DMAPD_DMAP_CONTAINER_RECORD_GET_PRIVATE (record);
-	record->priv->id = nextid++;
+	record->priv->id = _nextid++;
 	record->priv->entries = NULL;
 	record->priv->full_db = NULL;
 }
 
 static void
-dmapd_dmap_container_record_finalize (GObject *object)
+_finalize (GObject *object)
 {
         DmapdDmapContainerRecord *db = DMAPD_DMAP_CONTAINER_RECORD (object);
 
@@ -175,12 +174,12 @@ dmapd_dmap_container_record_class_init (DmapdDmapContainerRecordClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	gobject_class->finalize = dmapd_dmap_container_record_finalize;
+	gobject_class->finalize = _finalize;
 
         g_type_class_add_private (klass, sizeof (DmapdDmapContainerRecordPrivate));
 
-	gobject_class->set_property = dmapd_dmap_container_record_set_property;
-	gobject_class->get_property = dmapd_dmap_container_record_get_property;
+	gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
 
 	g_object_class_override_property (gobject_class, PROP_NAME, "name");
 
@@ -192,18 +191,18 @@ dmapd_dmap_container_record_class_init (DmapdDmapContainerRecordClass *klass)
 }
 
 static void
-dmapd_dmap_container_record_interface_init (gpointer iface, gpointer data)
+_dmap_container_record_interface_init (gpointer iface, gpointer data)
 {
 	DmapContainerRecordInterface *dmap_container_record = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_container_record) == DMAP_TYPE_CONTAINER_RECORD);
 
-	dmap_container_record->get_id = dmapd_dmap_container_record_get_id;
-	dmap_container_record->add_entry = dmapd_dmap_container_record_add_entry;
-	dmap_container_record->get_entry_count = dmapd_dmap_container_record_get_entry_count;
-	dmap_container_record->get_entries = dmapd_dmap_container_record_get_entries;
+	dmap_container_record->get_id = _get_id;
+	dmap_container_record->add_entry = _add_entry;
+	dmap_container_record->get_entry_count = _get_entry_count;
+	dmap_container_record->get_entries = _get_entries;
 }
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapContainerRecord, dmapd_dmap_container_record, G_TYPE_OBJECT, 
 			G_IMPLEMENT_INTERFACE (DMAP_TYPE_CONTAINER_RECORD,
-					       dmapd_dmap_container_record_interface_init))
+					       _dmap_container_record_interface_init))
