@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __DMAPD_DMAP_CONTAINER_RECORD
-#define __DMAPD_DMAP_CONTAINER_RECORD
+#ifndef _DMAPD_DMAP_CONTAINER_RECORD_H
+#define _DMAPD_DMAP_CONTAINER_RECORD_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -58,6 +58,6 @@ typedef struct {
 
 GType dmapd_dmap_container_record_get_type (void);
 
-#endif /* __DMAPD_DMAP_CONTAINER_RECORD */
-
 G_END_DECLS
+
+#endif
