@@ -68,7 +68,7 @@ _path_match (gpointer key, gpointer val, gpointer user_data)
 static guint
 _lookup_id_by_location (const DmapDb *db, const gchar *location)
 {
-	guint fnval;
+	guint fnval = DMAP_DB_ID_BAD;
 	struct loc_id user_data;
 
 	user_data.location = location;
@@ -78,8 +78,6 @@ _lookup_id_by_location (const DmapDb *db, const gchar *location)
 		(GHRFunc) _path_match,
 		(gpointer) &user_data)) {
 		fnval = user_data.id;
-	} else {
-		fnval = 0;
 	}
 
 	return fnval;
@@ -88,11 +86,16 @@ _lookup_id_by_location (const DmapDb *db, const gchar *location)
 static DmapRecord *
 _lookup_by_id (const DmapDb *db, guint id)
 {
-	DmapRecord *record;
+	DmapRecord *record = NULL;
+
+	if (DMAP_DB_ID_BAD == id) {
+		goto done;
+	}
 
 	record = g_hash_table_lookup (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, GUINT_TO_POINTER (id));
 	g_object_ref (record);
 
+done:
 	return record;
 }
 
@@ -131,19 +134,33 @@ _cache_read (const gchar *path)
 static guint
 _add_with_id (DmapDb *db, DmapRecord *record, guint id, GError **error)
 {
-	if (id > 0) {
-		g_hash_table_insert (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, GUINT_TO_POINTER (id), record);
+	if (DMAP_DB_ID_BAD == id) {
+		g_set_error(error,
+		            DMAP_ERROR,
+	                    DMAP_STATUS_DB_BAD_ID,
+	                   "Bad record identifier provided");
+		goto done;
 	}
 
+	g_hash_table_insert (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db,
+	                     GUINT_TO_POINTER (id),
+	                     record);
+
+done:
 	return id;
 }
 
 static guint
 _add_no_cache (DmapDb *db, DmapRecord *record, GError **error)
 {
-	g_object_ref (record);
+	guint id;
 
-	return _add_with_id (db, record, _nextid--, error);
+	id = _add_with_id (db, record, _nextid--, error);
+	if (DMAP_DB_ID_BAD != id) {
+		g_object_ref (record);
+	}
+
+	return id;
 }
 
 static void
@@ -171,7 +188,11 @@ _load_cached_records (DmapDb *db, const gchar *db_dir, DmapRecordFactory *factor
 						DmapRecord *record = dmap_record_factory_create (factory, NULL, &error);
 						if (NULL != record) {
 							if (dmap_record_set_from_blob (record, blob)) {
-								_add_no_cache (DMAP_DB (db), record, NULL);
+								_add_no_cache (DMAP_DB (db), record, &error);
+								if (NULL != error) {
+									g_warning("Unable to add record for %s: %s", path, error->message);
+									g_clear_error(&error);
+								}
 							} else {
 								g_warning ("Removing stale cache entry %s\n", path);
 								g_unlink (path);
@@ -225,27 +246,34 @@ _add_path (DmapDb *db, const gchar *path, GError **error)
 	guint id = 0;
 	DmapRecord *record;
 	DmapRecordFactory *factory = NULL;
+	char *format = NULL;
+	const gchar * const *acceptable_formats = NULL;
 
 	g_object_get (db, "record-factory", &factory, NULL);
 	g_assert (factory);
 
 	record = dmap_record_factory_create (factory, (gpointer) path, error);
-	if (record) {
-		char *format = NULL;
-		const gchar * const *acceptable_formats = NULL;
+	if (NULL == record) {
+		g_set_error(error,
+		            DMAP_ERROR,
+		            DMAP_STATUS_FAILED,
+		           "Error creating record from %s",
+		            path);
+		goto done;
+	}
 
-		g_object_get (record, "format", &format, NULL);
-		g_object_get (db, "acceptable-formats", &acceptable_formats, NULL);
+	g_object_get (record, "format", &format, NULL);
+	g_object_get (db, "acceptable-formats", &acceptable_formats, NULL);
 
-		if (! acceptable_formats || g_strv_contains(acceptable_formats, format)) {
-			id = _add (db, record, error);
-		}
+	if (! acceptable_formats || g_strv_contains(acceptable_formats, format)) {
+		id = _add (db, record, error);
+	}
 
-		if (NULL != format) {
-			g_free (format);
-		}
+	g_object_unref (record);
 
-		g_object_unref (record);
+done:
+	if (NULL != format) {
+		g_free (format);
 	}
 
 	return id;
