@@ -42,10 +42,10 @@ static void dmapd_dmap_db_init (DmapdDmapDb *db)
 }
 
 static void
-dmapd_dmap_db_set_property (GObject *object,
-                            guint prop_id,
-			    const GValue *value,
-			    GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
         DmapdDmapDb *db = DMAPD_DMAP_DB (object);
 
@@ -55,8 +55,9 @@ dmapd_dmap_db_set_property (GObject *object,
 			db->priv->db_dir = g_value_dup_string (value);
 			break;
 		case PROP_RECORD_FACTORY:
-			if (db->priv->record_factory)
+			if (db->priv->record_factory) {
 				g_object_unref (db->priv->record_factory);
+			}
 			db->priv->record_factory = DMAP_RECORD_FACTORY (g_value_get_pointer (value));
 			break;	
 		case PROP_ACCEPTABLE_FORMATS:
@@ -69,10 +70,7 @@ dmapd_dmap_db_set_property (GObject *object,
 }
 
 static void
-dmapd_dmap_db_get_property (GObject *object,
-                            guint prop_id,
-			    GValue *value,
-			    GParamSpec *pspec)
+_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
         DmapdDmapDb *db = DMAPD_DMAP_DB (object);
 
@@ -98,8 +96,8 @@ static void dmapd_dmap_db_class_init (DmapdDmapDbClass *klass)
 
 	g_type_class_add_private (klass, sizeof (DmapdDmapDbPrivate));
 
-	gobject_class->set_property = dmapd_dmap_db_set_property;
-	gobject_class->get_property = dmapd_dmap_db_get_property;
+	gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
 	/* FIXME: implement finalize */
 
 	g_object_class_install_property (gobject_class, PROP_RECORD_FACTORY,
@@ -122,55 +120,63 @@ static void dmapd_dmap_db_class_init (DmapdDmapDbClass *klass)
 					 		       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 	}
 
-static guint add (DmapDb *db, DmapRecord *record)
+static guint
+_add (DmapDb *db, DmapRecord *record, GError **error)
 {
-	return DMAPD_DMAP_DB_GET_CLASS (db)->add (db, record);
+	return DMAPD_DMAP_DB_GET_CLASS (db)->add (db, record, error);
 }
 
-static guint add_with_id (DmapDb *db, DmapRecord *record, guint id)
+static guint
+_add_with_id (DmapDb *db, DmapRecord *record, guint id, GError **error)
 {
-	return DMAPD_DMAP_DB_GET_CLASS (db)->add_with_id (db, record, id);
+	return DMAPD_DMAP_DB_GET_CLASS (db)->add_with_id (db, record, id, error);
 }
 
-static guint add_path (DmapDb *db, const gchar *path)
+static guint
+_add_path (DmapDb *db, const gchar *path, GError **error)
 {
-	return DMAPD_DMAP_DB_GET_CLASS (db)->add_path (db, path);
+	return DMAPD_DMAP_DB_GET_CLASS (db)->add_path (db, path, error);
 }
 
-DmapRecord *lookup_by_id (const DmapDb *db, guint id)
+static DmapRecord *
+_lookup_by_id (const DmapDb *db, guint id)
 {
 	return DMAPD_DMAP_DB_GET_CLASS (db)->lookup_by_id (db, id);
 }
 
-static guint lookup_id_by_location (const DmapDb *db, const gchar *location)
+static guint
+_lookup_id_by_location (const DmapDb *db, const gchar *location)
 {
 	return DMAPD_DMAP_DB_GET_CLASS (db)->lookup_id_by_location (db, location);
 }
 
-static void foreach (const DmapDb *db, DmapIdRecordFunc func, gpointer data)
+static void
+_foreach (const DmapDb *db, DmapIdRecordFunc func, gpointer data)
 {
 	return DMAPD_DMAP_DB_GET_CLASS (db)->foreach (db, func, data);
 }
 
-static gint64 count (const DmapDb *db)
+static gint64
+_count (const DmapDb *db)
 {
 	return DMAPD_DMAP_DB_GET_CLASS (db)->count (db);
 }
 
-static void dmapd_dmap_db_interface_init (gpointer iface, gpointer data)
+static void
+_dmap_db_interface_init (gpointer iface, gpointer data)
 {
 	DmapDbInterface *dmap_db = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_db) == DMAP_TYPE_DB);
 
-	dmap_db->add = add;
-	dmap_db->add_with_id = add_with_id;
-	dmap_db->add_path = add_path;
-	dmap_db->lookup_by_id = lookup_by_id;
-	dmap_db->lookup_id_by_location = lookup_id_by_location;
-	dmap_db->foreach = foreach;
-	dmap_db->count = count;
+	dmap_db->add = _add;
+	dmap_db->add_with_id = _add_with_id;
+	dmap_db->add_path = _add_path;
+	dmap_db->lookup_by_id = _lookup_by_id;
+	dmap_db->lookup_id_by_location = _lookup_id_by_location;
+	dmap_db->foreach = _foreach;
+	dmap_db->count = _count;
 }
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapDb, dmapd_dmap_db, G_TYPE_OBJECT, 
-			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, dmapd_dmap_db_interface_init))
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, _dmap_db_interface_init))
