@@ -23,7 +23,7 @@
 #include "dmapd-dpap-record.h"
 #include "dmapd-dpap-record-factory.h"
 
-static DmapdDmapImageRecordFactory *factory_singleton;
+static DmapdDmapImageRecordFactory *_factory_singleton;
 
 struct DmapdDmapImageRecordFactoryPrivate {
         PhotoMetaReader *photo_meta_reader;
@@ -35,17 +35,18 @@ enum {
 };
 
 static void
-dmapd_dpap_record_factory_set_property (GObject *object,
-                                        guint prop_id,
-                                        const GValue *value,
-                                        GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
         DmapdDmapImageRecordFactory *factory = DMAPD_DPAP_RECORD_FACTORY (object);
 
         switch (prop_id) {
                 case PROP_META_READER:
-			if (factory->priv->photo_meta_reader)
+			if (factory->priv->photo_meta_reader) {
 				g_object_unref (factory->priv->photo_meta_reader);
+			}
                         factory->priv->photo_meta_reader = PHOTO_META_READER (g_value_get_pointer (value));
                         break;
                 default:
@@ -55,10 +56,7 @@ dmapd_dpap_record_factory_set_property (GObject *object,
 }
 
 static void
-dmapd_dpap_record_factory_get_property (GObject *object,
-                                        guint prop_id,
-                                        GValue *value,
-                                        GParamSpec *pspec)
+_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
         DmapdDmapImageRecordFactory *factory = DMAPD_DPAP_RECORD_FACTORY (object);
 
@@ -73,18 +71,21 @@ dmapd_dpap_record_factory_get_property (GObject *object,
 }
 
 DmapRecord *
-dmapd_dpap_record_factory_create  (DmapRecordFactory *factory, gpointer user_data)
+dmapd_dpap_record_factory_create(DmapRecordFactory *factory,
+                                 gpointer user_data,
+                                 GError **error)
 {
 	return DMAP_RECORD (dmapd_dpap_record_new ((const char *) user_data, DMAPD_DPAP_RECORD_FACTORY (factory)->priv->photo_meta_reader));
 }
 
-static GObject *dmapd_dpap_record_factory_constructor (GType type,
-                               guint n_construct_properties,
-                               GObjectConstructParam *construct_properties)
+static GObject *
+_constructor (GType type,
+              guint n_construct_properties,
+              GObjectConstructParam *construct_properties)
 {
         GObject *object;
 
-        if (! factory_singleton) {
+        if (! _factory_singleton) {
                 DmapdDmapImageRecordFactoryClass *klass;
                 GObjectClass *parent_class;
                 klass = DMAPD_DPAP_RECORD_FACTORY_CLASS (
@@ -93,9 +94,9 @@ static GObject *dmapd_dpap_record_factory_constructor (GType type,
                 object = G_OBJECT_CLASS (parent_class)->constructor (type,
                                                         n_construct_properties,
                                                         construct_properties);
-                factory_singleton = DMAPD_DPAP_RECORD_FACTORY (object);
+                _factory_singleton = DMAPD_DPAP_RECORD_FACTORY (object);
         } else {
-                object = g_object_ref (G_OBJECT (factory_singleton));
+                object = g_object_ref (G_OBJECT (_factory_singleton));
         }
 
         return object;
@@ -114,9 +115,9 @@ dmapd_dpap_record_factory_class_init (DmapdDmapImageRecordFactoryClass *klass)
 
         g_type_class_add_private (klass, sizeof (DmapdDmapImageRecordFactoryPrivate));
 
-        gobject_class->set_property = dmapd_dpap_record_factory_set_property;
-        gobject_class->get_property = dmapd_dpap_record_factory_get_property;
-	gobject_class->constructor  = dmapd_dpap_record_factory_constructor;
+        gobject_class->set_property = _set_property;
+        gobject_class->get_property = _get_property;
+	gobject_class->constructor  = _constructor;
 
         g_object_class_install_property (gobject_class, PROP_META_READER,
                                          g_param_spec_pointer ("meta-reader",
@@ -127,7 +128,7 @@ dmapd_dpap_record_factory_class_init (DmapdDmapImageRecordFactoryClass *klass)
 }
 
 static void
-dmapd_dpap_record_factory_interface_init (gpointer iface, gpointer data)
+_dmap_record_factory_interface_init (gpointer iface, gpointer data)
 {
 	DmapRecordFactoryInterface *factory = iface;
 
@@ -138,4 +139,4 @@ dmapd_dpap_record_factory_interface_init (gpointer iface, gpointer data)
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapImageRecordFactory, dmapd_dpap_record_factory, G_TYPE_OBJECT, 
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD_FACTORY,
-					        dmapd_dpap_record_factory_interface_init))
+					        _dmap_record_factory_interface_init))
