@@ -114,7 +114,7 @@ _set_property (GObject *object,
 			if (record->priv->thumbnail) {
 				g_array_unref(record->priv->thumbnail);
 			}
-			record->priv->thumbnail = g_value_dup_boxed (value);
+			record->priv->thumbnail = g_value_get_boxed (value);
 			break;
 		case PROP_MTIME:
 			record->priv->mtime = g_value_get_int (value);
