@@ -30,13 +30,13 @@
 #include "photo-meta-reader-vips.h"
 #include "dmapd-dpap-record.h"
 
-const int DEFAULT_MAX_THUMBNAIL_WIDTH = 128;
+static const int _DEFAULT_MAX_THUMBNAIL_WIDTH = 128;
 
 #define THUMBNAIL "jpeg-thumbnail-data"
 #define MULTISCAN "jpeg-multiscan"
 
 static GOptionGroup *
-photo_meta_reader_vips_get_option_group (PhotoMetaReader * reader)
+_get_option_group (PhotoMetaReader * reader)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 
@@ -54,7 +54,7 @@ photo_meta_reader_vips_get_option_group (PhotoMetaReader * reader)
 }
 
 static gboolean
-jpeg_is_multiscan (VipsImage *in)
+_jpeg_is_multiscan (VipsImage *in)
 {
 	g_assert (VIPS_IS_IMAGE (in));
 
@@ -83,7 +83,7 @@ _done:
  * bilinear interpolation to get the exact size we want.
  */
 static int
-calculate_shrink (PhotoMetaReader *reader, int width, int height, double *residual)
+_calculate_shrink (PhotoMetaReader *reader, int width, int height, double *residual)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 
@@ -92,7 +92,7 @@ calculate_shrink (PhotoMetaReader *reader, int width, int height, double *residu
 	g_object_get (reader, "max-thumbnail-width", &max_thumbnail_width, NULL);
 
 	if (0 == max_thumbnail_width) {
-		max_thumbnail_width = DEFAULT_MAX_THUMBNAIL_WIDTH;
+		max_thumbnail_width = _DEFAULT_MAX_THUMBNAIL_WIDTH;
 	}
 
 	g_debug ("    Maximum thumbnail width is %d.", max_thumbnail_width);
@@ -123,27 +123,30 @@ calculate_shrink (PhotoMetaReader *reader, int width, int height, double *residu
 
 /* Find the best jpeg preload shrink. */
 static int
-thumbnail_find_jpegshrink (PhotoMetaReader *reader, VipsImage *im)
+_find_jpegshrink (PhotoMetaReader *reader, VipsImage *im)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 	g_assert (VIPS_IS_IMAGE (im));
 
-	int shrink = calculate_shrink (reader, im->Xsize, im->Ysize, NULL);
+	int shrink = _calculate_shrink (reader, im->Xsize, im->Ysize, NULL);
+	int value;
 
 	if (shrink >= 8) {
-		return 8;
+		value = 8;
 	} else if (shrink >= 4) {
-		return 4;
+		value = 4;
 	} else if (shrink >= 2) {
-		return 2;
+		value = 2;
 	} else  {
-		return 1;
+		value = 1;
 	}
+
+	return value;
 }
 
 /* Try to read an embedded thumbnail. */
 static VipsImage *
-thumbnail_get_thumbnail (PhotoMetaReader *reader, VipsImage *im)
+_get_thumbnail (PhotoMetaReader *reader, VipsImage *im)
 {
 	void *ptr;
 	size_t size;
@@ -170,7 +173,7 @@ thumbnail_get_thumbnail (PhotoMetaReader *reader, VipsImage *im)
 	}
 	g_debug ("    Embedded JPEG thumbnail size is %zd.", size);
 
-	(void) calculate_shrink (reader, thumb->Xsize, thumb->Ysize, &residual);
+	(void) _calculate_shrink (reader, thumb->Xsize, thumb->Ysize, &residual);
 	if (residual > 1.0) { 
 		g_warning ("    Embedded JPEG thumbnail too small.\n"); 
 		g_object_unref (thumb); 
@@ -179,7 +182,7 @@ thumbnail_get_thumbnail (PhotoMetaReader *reader, VipsImage *im)
 	}
 
 	/* Reload with the correct downshrink. */
-	jpegshrink = thumbnail_find_jpegshrink (reader, thumb);
+	jpegshrink = _find_jpegshrink (reader, thumb);
 	g_debug ("    Loading embedded JPEG thumbnail with factor %d preshrink.", jpegshrink);
 
 	g_object_unref (thumb);
@@ -202,7 +205,7 @@ _done:
  * VIPS to load a lower resolution version.
  */
 static VipsImage *
-thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filename)
+_thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filename)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 	g_assert (VIPS_IS_IMAGE (process));
@@ -233,7 +236,7 @@ thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filena
 		vips_object_local (process, im);
 
 		/* Try to read an embedded thumbnail. If we find one, use that instead. */
-		thumb = thumbnail_get_thumbnail (reader, im);
+		thumb = _get_thumbnail (reader, im);
 		if (NULL != thumb) {
 			vips_object_local (process, thumb);
 
@@ -246,7 +249,7 @@ thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filena
 			vips_object_local (VIPS_OBJECT (thumb), im);
 
 			im = thumb;
-		} else if (jpeg_is_multiscan (im)) {
+		} else if (_jpeg_is_multiscan (im)) {
 			/* libjpeg handles multiscan JPEGs differently.
 			 * Avoid this because of memory use on small devices.
 			 */
@@ -257,7 +260,7 @@ thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filena
 
 			g_debug ("    Processing main JPEG image.");
 
-			jpegshrink = thumbnail_find_jpegshrink (reader, im);
+			jpegshrink = _find_jpegshrink (reader, im);
 
 			g_debug ("    Loading JPEG with factor %d preshrink", jpegshrink);
 			if (vips_foreign_load (filename, &im,
@@ -286,7 +289,7 @@ _done:
 }
 
 static gboolean
-thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in, void **thumb, size_t *size)
+_thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in, void **thumb, size_t *size)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 	g_assert (VIPS_IS_IMAGE (process));
@@ -326,7 +329,7 @@ thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in, v
 		in = t[1];
 	}
 
-	shrink = calculate_shrink (reader, in->Xsize, in->Ysize, &residual);
+	shrink = _calculate_shrink (reader, in->Xsize, in->Ysize, &residual);
 
 	g_debug ("    Integer shrink by %d.", shrink);
 
@@ -374,27 +377,29 @@ _done:
 }
 
 static const char *
-photo_meta_reader_vips_get_str (VipsImage *im, const char *field)
+_get_str (VipsImage *im, const char *field)
 {
 	g_assert (VIPS_IS_IMAGE (im));
 	g_assert (NULL != field);
 
-	const char *str;
+	const char *str = NULL;
 
-	if (!vips_image_get_typeof (im, field)) 
-		return NULL;
+	if (!vips_image_get_typeof (im, field)) {
+		goto done;
+	}
 
 	if (vips_image_get_string (im, field, &str)) {
 		g_warning ("Failed to read %s from %s: %s", field, im->filename, vips_error_buffer ());
 		vips_error_clear ();
-		return NULL;
+		goto done;
 	}
 
+done:
 	return str; 
 }
 
 static gboolean
-photo_meta_reader_vips_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
+_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 	g_assert (IS_DMAP_IMAGE_RECORD (record));
@@ -466,12 +471,12 @@ photo_meta_reader_vips_read (PhotoMetaReader *reader, DmapImageRecord *record, c
 		g_object_set (record, "aspect-ratio", aspect_ratio, NULL);
 	}
 
-	if ((str = photo_meta_reader_vips_get_str (im, "exif-User Comment"))) {
+	if ((str = _get_str (im, "exif-User Comment"))) {
 		g_debug ("    Tag comments is %s.", str);
 		g_object_set (record, "comments", str, NULL);
 	}
 
-	if ((str = photo_meta_reader_vips_get_str (im, "exif-Date and Time"))) {
+	if ((str = _get_str (im, "exif-Date and Time"))) {
 		// Format is: "2007:10:05 00:20:26 (ASCII, 20 bytes)".
 		if (strlen (str) < 19) {
 			g_warning ("Bad timestamp string in %s: %s", im->filename, str);
@@ -493,13 +498,13 @@ photo_meta_reader_vips_read (PhotoMetaReader *reader, DmapImageRecord *record, c
 		}
 	}
 
-	thumb = thumbnail_open (reader, process, path);
+	thumb = _thumbnail_open (reader, process, path);
 	if (NULL == thumb) {
 		g_warning ("Could not open thumbnail for %s", path);
 		goto _done;
 	}
 
-	if (thumbnail_shrink (reader, process, thumb, &thumbnail_data, &thumbnail_size)) {
+	if (_thumbnail_shrink (reader, process, thumb, &thumbnail_data, &thumbnail_size)) {
 		g_debug ("    Thumbnail is %ld bytes.", thumbnail_size);
 		thumbnail_array = g_array_sized_new (FALSE, FALSE, 1, thumbnail_size);
 		if (NULL == thumbnail_array) {
@@ -564,9 +569,8 @@ photo_meta_reader_vips_class_init (PhotoMetaReaderVipsClass * klass)
 
 	/* g_type_class_add_private (klass, sizeof (PhotoMetaReaderVipsPrivate)); */
 
-	photo_meta_reader->read = photo_meta_reader_vips_read;
-	photo_meta_reader->get_option_group =
-		photo_meta_reader_vips_get_option_group;
+	photo_meta_reader->read = _read;
+	photo_meta_reader->get_option_group = _get_option_group;
 }
 
 static void photo_meta_reader_vips_register_type (GTypeModule * module);
@@ -584,5 +588,4 @@ dmapd_module_unload (GTypeModule * module)
 	return TRUE;
 }
 
-G_DEFINE_DYNAMIC_TYPE (PhotoMetaReaderVips,
-		       photo_meta_reader_vips, TYPE_PHOTO_META_READER)
+G_DEFINE_DYNAMIC_TYPE (PhotoMetaReaderVips, photo_meta_reader_vips, TYPE_PHOTO_META_READER)
