@@ -31,10 +31,10 @@ enum {
 };
 
 static void
-photo_meta_reader_set_property (GObject * object,
-                                guint prop_id,
-				const GValue * value,
-				GParamSpec * pspec)
+_set_property (GObject * object,
+               guint prop_id,
+               const GValue * value,
+               GParamSpec * pspec)
 {
 	PhotoMetaReader *reader = PHOTO_META_READER (object);
 
@@ -49,10 +49,10 @@ photo_meta_reader_set_property (GObject * object,
 }
 
 static void
-photo_meta_reader_get_property (GObject *object,
-                                guint prop_id,
-                                GValue *value,
-				GParamSpec *pspec)
+_get_property (GObject *object,
+               guint prop_id,
+               GValue *value,
+               GParamSpec *pspec)
 {
 	PhotoMetaReader *reader = PHOTO_META_READER (object);
 
@@ -79,8 +79,8 @@ photo_meta_reader_class_init (PhotoMetaReaderClass *klass)
 
 	g_type_class_add_private (klass, sizeof (PhotoMetaReaderPrivate));
 
-	gobject_class->set_property = photo_meta_reader_set_property;
-	gobject_class->get_property = photo_meta_reader_get_property;
+	gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
 
 	g_object_class_install_property (gobject_class,
 	                                 PROP_MAX_THUMBNAIL_WIDTH,
@@ -95,12 +95,14 @@ photo_meta_reader_class_init (PhotoMetaReaderClass *klass)
 
 G_DEFINE_TYPE (PhotoMetaReader, photo_meta_reader, G_TYPE_OBJECT)
 
-gboolean photo_meta_reader_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
+gboolean
+photo_meta_reader_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 {
 	return PHOTO_META_READER_GET_CLASS (reader)->read (reader, record, path);
 }
 
-GOptionGroup *photo_meta_reader_get_option_group (PhotoMetaReader *reader)
+GOptionGroup *
+photo_meta_reader_get_option_group (PhotoMetaReader *reader)
 {
 	return PHOTO_META_READER_GET_CLASS (reader)->get_option_group (reader);
 }
